@@ -1,14 +1,14 @@
 "closedp.h" <- function(X, dfreq=FALSE, m="Mh", h="Poisson", a=2)
 {
 
+        X<-as.matrix(X)
+        t <- ifelse(dfreq,dim(X)[2]-1,dim(X)[2])
+
     #####################################################################################################################################
     # Validation des arguments fournis en entre
     
     # Argument dfreq
-    if(!is.logical(dfreq)||length(dfreq)!=1) stop("'dfreq' must be a logical object of length 1")
-
-        X <- as.matrix(X)
-        t <- if(dfreq) dim(X)[2]-1 else dim(X)[2]
+    if(!is.logical(dfreq)||!isTRUE(all.equal(length(dfreq),1))) stop("'dfreq' must be a logical object of length 1")
 
     # Argument X
     X <- as.matrix(X)
@@ -21,15 +21,17 @@
     }
     
     # Argument m
-    if(length(m)!=1) stop("'m' must be of length 1")
-    if(m!="Mh"&&m!="Mth") stop("'m' can only take the values 'Mh' and 'Mth'")
+    if(!isTRUE(all.equal(length(m),1))) stop("'m' must be of length 1")
+    if(!identical(m,"Mh")&&!identical(m,"Mth"))
+              stop("'m' can only take the values 'Mh' and 'Mth'")
     
     # Argument h
-    if(length(h)!=1) stop("'h' must be of length 1")
-    if(!is.function(h)&&h!="Poisson") stop("'h' must be a function or a charater strings taking the value 'Poisson'")
+    if(!isTRUE(all.equal(length(h),1))) stop("'h' must be of length 1")
+    if(!is.function(h)&&!identical(h,"Poisson"))
+    stop("'h' must be a function or a charater strings taking the value 'Poisson'")
     
     # Argument a
-    if(length(a)!=1) stop("'a' must be of length 1")
+    if(!isTRUE(all.equal(length(a),1))) stop("'h' must be of length 1")
     if (!is.numeric(a)) stop("'a' must be a numeric value")
     
     #####################################################################################################################################
@@ -38,10 +40,10 @@
         Y <- histfreq.t(X,dfreq=dfreq)
         nbcap <- apply(histpos, 1, sum)
 
-        mX2 <- if (is.function(h)) h(nbcap) else if (h=="Poisson") a^nbcap - 1 
-        mX <- if (m=="Mh") cbind(nbcap,mX2) else if(m=="Mth") cbind(histpos,mX2)
+        mX2 <- if (identical(h,"Poisson")) a^nbcap - 1 else if (is.function(h)) h(nbcap)
+        mX <- if (identical(m,"Mh")) cbind(nbcap,mX2) else if(identical(m,"Mth")) cbind(histpos,mX2)
         anaM <- glm(Y~mX,family=poisson)
-        NM <- sum(na.rm=TRUE,Y)+exp(anaM$coef[1]) # calcul de la taille de la population N
+        NM <- sum(Y)+exp(anaM$coef[1]) # calcul de la taille de la population N
         varcovM <- summary(anaM)$cov.unscaled
         erreurtypeM <- sqrt(exp(anaM$coef[1])+(exp(2*anaM$coef[1]))*varcovM[1,1])
         M <- matrix(c(NM,erreurtypeM,anaM$dev,anaM$df.residual,anaM$aic),nrow=1)
@@ -49,9 +51,9 @@
 
         # Prparation des sorties
         closedp.call<-match.call()
-        modelname <- if (is.function(h)) paste(m,closedp.call$h) else if(h=="Poisson") paste(m,paste(h,a,sep=""))
+        modelname <- if (is.function(h)) paste(m,closedp.call$h) else if(identical(h,"Poisson")) paste(m,paste(h,a,sep=""))
         dimnames(M) <- list(modelname,c("abundance","stderr","deviance","df","AIC"))
-        ans <- list(n=sum(na.rm=TRUE,Y),results=M,glm=anaM)
+        ans <- list(n=sum(Y),results=M,glm=anaM)
         class(ans) <- "closedp.custom"
         ans
 
